@@ -1,7 +1,5 @@
 """
-Type annotations for sso-oidc service client.
-
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
+Main interface for sso-oidc service client
 
 Usage::
 
@@ -51,8 +49,7 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sso-oidc.html#SSOOIDC.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
+    [SSOOIDC.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client)
     """
 
     meta: ClientMeta
@@ -60,8 +57,7 @@ class SSOOIDCClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can-paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
         """
 
     def create_token(
@@ -76,8 +72,7 @@ class SSOOIDCClient:
         redirectUri: str = None,
     ) -> CreateTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create-token)
+        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
         """
 
     def generate_presigned_url(
@@ -88,22 +83,19 @@ class SSOOIDCClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate-presigned-url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
         """
 
     def register_client(
         self, clientName: str, clientType: str, scopes: List[str] = None
     ) -> RegisterClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register-client)
+        [Client.register_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         """
 
     def start_device_authorization(
         self, clientId: str, clientSecret: str, startUrl: str
     ) -> StartDeviceAuthorizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start-device-authorization)
+        [Client.start_device_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
         """
